multidim.Simplex
================

.. currentmodule:: multidim

.. autoclass:: Simplex

   

      .. autosummary::
         :toctree:
      



   

      .. autosummary::
         :toctree:
      
         Simplex.boundary
         Simplex.height
         Simplex.mass
         Simplex.positive
         Simplex.representative

